@@ -3,17 +3,16 @@ BEGIN {
   $POE::Component::IRC::Plugin::Logger::AUTHORITY = 'cpan:HINRIK';
 }
 BEGIN {
-  $POE::Component::IRC::Plugin::Logger::VERSION = '6.58';
+  $POE::Component::IRC::Plugin::Logger::VERSION = '6.59';
 }
 
 use strict;
 use warnings FATAL => 'all';
-use Cwd qw(abs_path);
 use Carp;
 use Encode::Guess;
 use Fcntl qw(O_WRONLY O_APPEND O_CREAT);
 use File::Glob ':glob';
-use File::Spec::Functions qw(catdir catfile);
+use File::Spec::Functions qw(catdir catfile rel2abs);
 use IO::Handle;
 use POE::Component::IRC::Plugin qw( :ALL );
 use POE::Component::IRC::Plugin::BotTraffic;
@@ -56,7 +55,7 @@ sub PCI_register {
     if (defined $self->{Path} && ! -d $self->{Path}) {
         mkdir $self->{Path}, $self->{dir_perm}
             or die 'Cannot create directory ' . $self->{Path} . ": $!; aborted";
-        $self->{Path} = abs_path($self->{Path});
+        $self->{Path} = rel2abs($self->{Path});
     }
 
     $self->{irc} = $irc;
